django-prototyper
===============


UI for generating django code 


Installation
-----------------

::

    # if you have python2
    python3 -m venv .env
    source .env/bin/activate


::

    pip install django-prototyper



Usage
-----------------


::

    prototyper ./myproject1



Then open your browser and go to http://localhost:8080/ and follow UI

